API Reference
=============

codegeneration
--------------
.. automodule:: goss.codegeneration
    :members:
    :inherited-members:


compilemodule
-------------
.. automodule:: goss.compilemodule
    :members:
    :inherited-members:


dolfinutils
-----------
.. automodule:: goss.dolfinutils
    :members:
    :inherited-members:

ode
---
.. automodule:: goss.ode
    :members:
    :inherited-members:

solvers
-------
.. automodule:: goss.solvers
    :members:
    :inherited-members:

systemsolver
------------
.. automodule:: goss.systemsolver
    :members:
    :inherited-members:
